@@ -1,4 +1,5 @@
-# Copyright 2001-2004 The Apache Software Foundation
+# Copyright 2001-2005 The Apache Software Foundation or its licensors, as
+# applicable.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -42,6 +43,7 @@ use subs qw(exit_shell exit_perl);
 
 my $orig_command;
 my $orig_cwd;
+my $orig_conf_opts;
 
 my %core_files  = ();
 my %original_t_perms = ();
@@ -231,6 +233,7 @@ sub getopts {
     my $req_wanted_args = Apache::TestRequest::wanted_args();
     my @argv = ();
     my %req_args = ();
+
     while (@ARGV) {
         my $val = shift @ARGV;
         if ($val =~ /^--?(.+)/) { # must have a leading - or --
@@ -249,6 +252,9 @@ sub getopts {
         push @argv, $val;
     }
 
+    # save the orig args (make a deep copy)
+    $orig_conf_opts = { %conf_opts };
+
     # fixup the filepath options on win32 (spaces, short names, etc.)
     if (Apache::TestConfig::WIN32) {
         for my $key (keys %conf_opts) {
@@ -746,11 +752,32 @@ sub run {
 }
 
 sub rerun {
+    my $vars = shift;
+
+    # in %$vars
+    # - httpd will be always set
+    # - apxs is optional
+
     $orig_cwd ||= Cwd::cwd();
     chdir $orig_cwd;
-    warning "rerunning '$orig_command' with new config opts";
+    my $new_opts = " -httpd $vars->{httpd}";
+    $new_opts .= " -apxs $vars->{apxs}" if $vars->{apxs};
+
+    my $new_command = $orig_command;
+
+    # strip any old bogus -httpd/-apxs
+    $new_command =~ s/--?httpd\s+$orig_conf_opts->{httpd}//
+        if $orig_conf_opts->{httpd};
+    $new_command =~ s/--?httpd\s+$orig_conf_opts->{httpd}//
+        if $orig_conf_opts->{httpd} and $vars->{apxs};
+
+    # add new opts
+    $new_command .= $new_opts;
+
+    warning "running with new config opts: $new_command";
+
     # use 'or die' to avoid warnings due to possible overrides of die
-    exec $orig_command or die "exec $orig_command has failed";
+    exec $new_command or die "exec $new_command has failed";
 }
 
 
@@ -834,13 +861,13 @@ sub scan_core_incremental {
         require IO::Dir;
         my @cores = ();
         for (IO::Dir->new($vars->{t_dir})->read) {
-            next unless -f;
+            my $file = catfile $vars->{t_dir}, $_;
+            next unless -f $file;
             next unless /$core_pat/o;
-            my $core = catfile $vars->{t_dir}, $_;
-            next if exists $core_files{$core} &&
-                $core_files{$core} == -M $core;
-            $core_files{$core} = -M $core;
-            push @cores, $core;
+            next if exists $core_files{$file} &&
+                $core_files{$file} == -M $file;
+            $core_files{$file} = -M $file;
+            push @cores, $file;
         }
         return @cores 
             ? join "\n", "server dumped core, for stacktrace, run:",
@@ -1237,8 +1264,6 @@ sub generate_script {
 
     my $body = "BEGIN { eval { require blib && blib->import; } }\n";
 
-    $body .= Apache::TestConfig->modperl_2_inc_fixup;
-
     my %args = @Apache::TestMM::Argv;
     while (my($k, $v) = each %args) {
         $v =~ s/\|/\\|/g;
@@ -1284,6 +1309,13 @@ sub exit_shell {
 sub skip_test_suite {
     my $no_doubt = shift;
 
+    # we can't prompt when STDIN is not attached to tty, unless we
+    # were told that's it OK via env var (in which case some program
+    # will feed the interactive prompts
+    unless (-t STDIN || $ENV{APACHE_TEST_INTERACTIVE_PROMPT_OK}) {
+        $no_doubt = 1;
+    }
+
     print qq[
 
 Running the test suite is important to make sure that the module that
